@@ -4,18 +4,15 @@ import (
 	"encoding/json"
 	"fmt"
 	"strings"
-
-	"github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 )
 
 //go:generate go run ./release_generate.go
 
 // Info holds version information
 type Info struct {
-	Version                    string
-	PreReleaseID               string
-	Metadata                   BuildMetadata
-	EKSServerSupportedVersions []string
+	Version      string
+	PreReleaseID string
+	Metadata     BuildMetadata
 }
 
 // BuildMetadata contains the semver build metadata:
@@ -34,7 +31,6 @@ func GetVersionInfo() Info {
 			GitCommit: gitCommit,
 			BuildDate: buildDate,
 		},
-		EKSServerSupportedVersions: v1alpha5.SupportedVersions(),
 	}
 }
 
